==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/nativemethods/JavaLangReflectConstructorNative.h <==
// public class soot.jimple.toolkits.pointer.nativemethods.JavaLangReflectConstructorNative

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ab89f2b4aa0e2b10 soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative
// @dep_class adf075d6a4c28634 soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

#include "soot/jimple/toolkits/pointer/nativemethods/NativeMethodClass.h"

#ifndef _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative_H_
#define _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$object;
struct _jc_soot_jimple_toolkits_pointer_representations_ReferenceVariable$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$sub_refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$object	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vmethods	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vtable	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vtype	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$method$simulateMethod$16021ad0ff992382(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$method_info$simulateMethod$16021ad0ff992382;

// Static methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$method$java__5flang__5freflect__5fConstructor__5fnewInstance$abba6326670b0397(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
extern struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$object *_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$method$v$db6f77b5e0d61c2e(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vmethods {
	void	(*simulateMethod$16021ad0ff992382)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vmethods	soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$refs {
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$sub_refs	soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$object {
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vtype _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/nativemethods/JavaLangReflectConstructorNative.h <==
// public class soot.jimple.toolkits.pointer.nativemethods.JavaLangReflectConstructorNative

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ab89f2b4aa0e2b10 soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative
// @dep_class adf075d6a4c28634 soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

#include "soot/jimple/toolkits/pointer/nativemethods/NativeMethodClass.h"

#ifndef _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative_H_
#define _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$object;
struct _jc_soot_jimple_toolkits_pointer_representations_ReferenceVariable$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$sub_refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$object	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vmethods	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vtable	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vtype	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$method$simulateMethod$16021ad0ff992382(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$method_info$simulateMethod$16021ad0ff992382;

// Static methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$method$java__5flang__5freflect__5fConstructor__5fnewInstance$abba6326670b0397(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$object *_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$method$v$db6f77b5e0d61c2e(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vmethods {
	void	(*simulateMethod$16021ad0ff992382)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vmethods	soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$refs {
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$sub_refs	soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$object {
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$vtype _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectConstructorNative_H_ */
